Module controls

Module controls 

Macros

make_controls
Eases the creation of large control schemes by accepting any number of tuples with with the type (A: Into<Action>, I: Into<UniversalInput>).

Structs

ControlScheme
A wrapper around a map of Actions to UniversalInputs.
Example:
MultiScheme
Helper type to be used for local multiplayer